@@ -1,6 +1,7 @@
 import logging
+from collections.abc import Sequence
 from types import TracebackType
-from typing import Optional, Sequence, Type
+from typing import Optional
 
 import aiohttp
 from aiohttp import ClientResponseError
@@ -34,7 +35,7 @@ class ConfigClient:
 
     async def __aexit__(
         self,
-        exc_type: Optional[Type[BaseException]],
+        exc_type: Optional[type[BaseException]],
         exc_val: Optional[BaseException],
         exc_tb: Optional[TracebackType],
     ) -> None:
@@ -84,3 +85,8 @@ class ConfigClient:
             is_existing = e.status == 400 and "already exists" in e.message
             if not ignore_existing or is_existing:
                 raise
+
+    async def delete_cluster(self, name: str) -> None:
+        assert self._client
+        async with self._client.delete(self._clusters_url / name) as resp:
+            resp.raise_for_status()
